==> librecad_2.0.4.orig.tar.gz: LibreCAD-2.0.4/librecad/src/ui/forms/qg_polylineoptions.h <==
/****************************************************************************
**
** This file is part of the LibreCAD project, a 2D CAD program
**
** Copyright (C) 2010 R. van Twisk (librecad@rvt.dds.nl)
** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
**
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software 
** Foundation and appearing in the file gpl-2.0.txt included in the
** packaging of this file.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
** This copyright notice MUST APPEAR in all copies of the script!  
**
**********************************************************************/
#ifndef QG_POLYLINEOPTIONS_H
#define QG_POLYLINEOPTIONS_H

#include "ui_qg_polylineoptions.h"

class RS_ActionInterface;
class RS_ActionDrawPolyline;

class QG_PolylineOptions : public QWidget, public Ui::QG_PolylineOptions
{
    Q_OBJECT

public:
    QG_PolylineOptions(QWidget* parent = 0, Qt::WindowFlags fl = 0);
    ~QG_PolylineOptions();

public slots:
    virtual void setAction( RS_ActionInterface * a, bool update );
    virtual void close();
    virtual void undo();
    virtual void updateRadius( const QString & s );
    virtual void updateAngle( const QString & s );
    virtual void updateDirection( bool );
    virtual void updateMode( int m );

protected:
    RS_ActionDrawPolyline* action;

protected slots:
    virtual void languageChange();

private:
    void destroy();

};

#endif // QG_POLYLINEOPTIONS_H

==> librecad_2.1.2.orig.tar.gz: LibreCAD-2.1.2/librecad/src/ui/forms/qg_polylineoptions.h <==
/****************************************************************************
**
** This file is part of the LibreCAD project, a 2D CAD program
**
** Copyright (C) 2010 R. van Twisk (librecad@rvt.dds.nl)
** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
**
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software 
** Foundation and appearing in the file gpl-2.0.txt included in the
** packaging of this file.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
** This copyright notice MUST APPEAR in all copies of the script!  
**
**********************************************************************/
#ifndef QG_POLYLINEOPTIONS_H
#define QG_POLYLINEOPTIONS_H

#include<memory>
#include<QWidget>

class RS_ActionInterface;
class RS_ActionDrawPolyline;
namespace Ui {
class Ui_PolylineOptions;
}

class QG_PolylineOptions : public QWidget
{
    Q_OBJECT

public:
    QG_PolylineOptions(QWidget* parent = 0, Qt::WindowFlags fl = 0);
    ~QG_PolylineOptions();

public slots:
    virtual void setAction( RS_ActionInterface * a, bool update );
    virtual void close();
    virtual void undo();
    virtual void updateRadius( const QString & s );
    virtual void updateAngle( const QString & s );
    virtual void updateDirection( bool );
    virtual void updateMode( int m );

protected:
    RS_ActionDrawPolyline* action;

protected slots:
    virtual void languageChange();

private:
    void destroy();
	std::unique_ptr<Ui::Ui_PolylineOptions> ui;
};

#endif // QG_POLYLINEOPTIONS_H
